==> ssb_dash_components-0.9.1.tar.gz: ssb_dash_components-0.9.1/README.md <==
# SSB Dash Components

_The [SSB Component Library](https://design.ssb.no/), available for Dash!_

## Components

| Component              | Available for Dash? |
| ---------------------- | ------------------- |
| Accordion              | :white_check_mark:  |
| Breadcrumb             |                     |
| Button                 | :white_check_mark:  |
| Cards                  |                     |
| Checkbox               |                     |
| Divider                |                     |
| Dropdown               | :white_check_mark:  |
| DropdownMultiple       | :white_check_mark:  |
| Fact Box               |                     |
| Footer                 |                     |
| Form Error             |                     |
| Glossary               | :white_check_mark:  |
| Graphs                 |                     |
| Header                 | :white_check_mark:  |
| Input                  | :white_check_mark:  |
| Key Figures            |                     |
| Links                  | :white_check_mark:                    |
| Map                    |                     |
| Pagination             |                     |
| Quote and Highlighting |                     |
| Radio Buttons          |                     |
| Responsive media       |                     |
| Reference              |                     |
| Search                 |                     |
| Site navigation        |                     |
| Sticky menu            |                     |
| Table                  |                     |
| Tabs                   | :white_check_mark:  |
| Tags                   |                     |
| Warnings and errors    | :white_check_mark:  |

==> ssb_dash_components-0.10.0.tar.gz: ssb_dash_components-0.10.0/README.md <==
# SSB Dash Components

_The [SSB Component Library](https://design.ssb.no/), available for Dash!_

## Components

| Component              | Available for Dash? |
| ---------------------- | ------------------- |
| Accordion              | :white_check_mark:  |
| Breadcrumb             |                     |
| Button                 | :white_check_mark:  |
| Cards                  |                     |
| Checkbox               | :white_check_mark:  |
| Dialog                 | :white_check_mark:  |
| Divider                |                     |
| Dropdown               | :white_check_mark:  |
| DropdownMultiple       | :white_check_mark:  |
| Fact Box               |                     |
| Footer                 |                     |
| Form Error             |                     |
| Glossary               | :white_check_mark:  |
| Graphs                 |                     |
| Header                 | :white_check_mark:  |
| Input                  | :white_check_mark:  |
| Key Figures            |                     |
| Links                  | :white_check_mark:  |
| Map                    |                     |
| Pagination             |                     |
| Paragraph              | :white_check_mark:  |
| Quote and Highlighting |                     |
| Radio Buttons          |                     |
| Responsive media       |                     |
| Reference              |                     |
| Search                 |                     |
| Site navigation        |                     |
| Sticky menu            |                     |
| Table                  |                     |
| Tabs                   | :white_check_mark:  |
| Tags                   |                     |
| Title                  | :white_check_mark:  |
| Warnings and errors    | :white_check_mark:  |
